Class: Lara::Credentials
- Inherits:
-
Object
- Object
- Lara::Credentials
- Defined in:
- lib/lara/credentials.rb
Overview
IMPORTANT: Do not hard-code your access key ID and secret in your code. Always use environment variables or a credentials file. Please note also that the access key secret is never sent directly via HTTP, but it is used to sign the request. If you suspect that your access key secret has been compromised, you can revoke it in the Lara dashboard.
Instance Attribute Summary collapse
-
#access_key_id ⇒ String
readonly
The access key ID.
-
#access_key_secret ⇒ Object
readonly
Returns the value of attribute access_key_secret.
Instance Method Summary collapse
-
#initialize(access_key_id, access_key_secret) ⇒ Credentials
constructor
A new instance of Credentials.
Constructor Details
#initialize(access_key_id, access_key_secret) ⇒ Credentials
Returns a new instance of Credentials.
21 22 23 24 |
# File 'lib/lara/credentials.rb', line 21 def initialize(access_key_id, access_key_secret) @access_key_id = access_key_id @access_key_secret = access_key_secret end |
Instance Attribute Details
#access_key_id ⇒ String (readonly)
Returns The access key ID.
17 18 19 |
# File 'lib/lara/credentials.rb', line 17 def access_key_id @access_key_id end |
#access_key_secret ⇒ Object (readonly)
Returns the value of attribute access_key_secret.
17 |
# File 'lib/lara/credentials.rb', line 17 attr_reader :access_key_id, :access_key_secret |